# Faythe Python Client

[![license](https://img.shields.io/badge/license-Apache%20v2.0-blue.svg)](LICENSE) [![PyPI version](https://badge.fury.io/py/faytheclient.svg)](https://badge.fury.io/py/faytheclient)

This is a client library for [Faythe](https://github.com/vCloud-DFTBA/faythe) built on the its API. It provides a Python API (the faytheclient module).

- **Python 3 only.**
- **This client is compatible with Faythe version >= v0.4.4.**

## Installation

Install the client:

```bash
python setup.py install
```

This package can be found on [PyPI](https://pypi.python.org/pypi/python-faytheclient).

```bash
pip install python-faytheclient
```

## Examples

The example can be found [here](./examples/).

- Create a copy of the environment variables example. Then adjust it:

```bash
cp .env.example .env
```

- Source the .env file:

```bash
source .env
```

- Run the example:

```bash
python example.py
```
